# eric7.EricNetwork.EricSslCertificatesInfoDialog

Module implementing a dialog to show SSL certificate infos.

### Global Attributes

None

### Classes

EricSslCertificatesInfoDialog | Class implementing a dialog to show SSL certificate infos.

### Functions

None

## EricSslCertificatesInfoDialog

Class implementing a dialog to show SSL certificate infos.

### Derived from

QDialog, Ui_EricSslCertificatesInfoDialog

### Class Attributes

None

### Class Methods

None

### Methods

EricSslCertificatesInfoDialog | Constructor

### Static Methods

None

#### EricSslCertificatesInfoDialog (Constructor)

EricSslCertificatesInfoDialog(certificateChain, parent=None)

Constructor

certificateChain
  SSL certificate chain (list of QSslCertificate)
parent
  reference to the parent widget (QWidget)

Up